@@ -3,13 +3,13 @@ package HTML::SiteTear;
 use 5.008;
 use strict;
 use warnings;
-use File::Basename;
+use File::Basename qw(basename);
 use File::Spec;
-use File::Path;
+use File::Path 2.0 qw(make_path);
 use File::Find;
-#use Cwd;
+use Cwd;
 use Carp;
-use base qw(Class::Accessor);
+use base qw(Class::Accessor::Fast);
 __PACKAGE__->mk_accessors( qw(source_path
                              site_root_path
                              site_root_url
@@ -19,7 +19,7 @@ __PACKAGE__->mk_accessors( qw(source_path
 use HTML::SiteTear::Root;
 use HTML::SiteTear::Page;
 
-use Data::Dumper;
+# use Data::Dumper;
 
 =head1 NAME
 
@@ -27,11 +27,11 @@ HTML::SiteTear - Make a separated copy of a part of the site
 
 =head1 VERSION
 
-Version 1.43
+Version 1.45
 
 =cut
 
-our $VERSION = '1.43';
+our $VERSION = '1.45';
 
 =head1 SYMPOSIS
 
@@ -78,8 +78,14 @@ sub new {
     
     $self->source_path or croak "source_path is not specified.\n";
     (-e $self->source_path) or croak $self->source_path." is not found.\n";
-    
+        
     if (-d $self->source_path) {
+        unless (File::Spec->file_name_is_absolute($self->source_path)) {
+            my $cwd = fix_dir_path(cwd);
+            $self->source_path(
+                URI::file->new($self->source_path)->abs($cwd)->file);
+        }
+        
         unless ($self->member_files) {
             my @htmlfiles;
             my $wanted = sub {
@@ -135,7 +141,7 @@ sub copy_to {
         }
     } else {
         my ($name, $dir) = fileparse($destination_path);
-        mkpath($dir);
+        make_path($dir);
         unless ($name) {
             $destination_path = File::Spec->catfile($dir,
                                                 basename($source_path));
@@ -147,7 +153,7 @@ sub copy_to {
     my $new_source_page = HTML::SiteTear::Page->new(
                                         'parent' => $root,
                                         'source_path' => $source_path);
-    $new_source_page->linkpath( basename($destination_path) );
+    $new_source_page->linkpath(basename($destination_path) );
     #$new_source_page->link_uri(URI::file->new(Cwd::abs_path($destination_path)));
     $new_source_page->link_uri(URI::file->new_abs($destination_path));
     $new_source_page->copy_to_linkpath;
@@ -172,32 +178,29 @@ sub copy_to_dir {
     $self->target_path($destination_path);
     my $root = HTML::SiteTear::Root->new(%$self);
     my $source_root_uri = $root->source_root_uri;
-    my $dest_uri = URI::file->new($destination_path);
-    my @results;
-    foreach my $file (@{$self->member_files}) {
-        my $a_member_file = $file;
-        unless (File::Spec->file_name_is_absolute($a_member_file)) {
-            #$a_member_file = File::Spec->rel2abs($a_member_file,
-            #                                    $self->source_path);
-            #$a_member_file = Cwd::abs_path($a_member_file);
-            $a_member_file = URI::file->new($a_member_file)
-                                   ->abs($self->source_path)->file;
-        }
-        my $page = HTML::SiteTear::Page->new(
-                                            'parent' => $root,
-                                            'source_path' => $a_member_file);
+    my $dest_uri = URI::file->new_abs($destination_path);
+    my @results = map {
+        my $a_member_file = do {
+            if (File::Spec->file_name_is_absolute($_)) {
+                $_;
+            }else {
+                URI::file->new($_)
+                    ->abs($self->source_path)->file;
+            }};
+        my $page = HTML::SiteTear::Page->new('parent' => $root,
+                                             'source_path' => $a_member_file);
         my $rel_from_source_root = $page->source_uri->rel($source_root_uri);
         my $abs_from_dest = $rel_from_source_root->abs($dest_uri);
         $page->link_uri($abs_from_dest);
         $page->copy_to_linkpath;
-        push @results, $page;
-    }
+        $page;
+    } @{$self->member_files};
     return \@results;
 }
 
 =head1 ABSOLUTE LINK
 
-The default behavior of HTML::SiteTear follows all of links in HTML files. In some case, there are links should not be followd. For example, if theare is a link to the top page of the site, all of files in the site will be copyied. Such links should be converted to absolute links (ex. "http://www.....").
+The default behavior of HTML::SiteTear follows all of links in HTML files. In some case, there are links should not be followd. For example, if theare is a link to the top page of the site, all of files in the site will be copyied. Such links should be converted to absolute links (e.g. "http://www.....").
 
 To convert links should not be followed into absolute links,
 
@@ -221,6 +224,10 @@ A URL corresponding to 'site_root_path' in WWW.
 
 =item *
 
+Relative links to upper level files from 'source_path' are automatically converted to absolute links.
+
+=item *
+
 To indicate links should be conveted to absolute links, enclose links in HTML files with specail comment tags <!-- begin abs_link --> and <!-- end abs_link -->
 
 =back
