@@ -2,18 +2,16 @@ package HTML::SiteTear::Page;
 
 use strict;
 use warnings;
-#use Cwd;
 use File::Spec;
-use File::Basename;
+use File::Basename qw(dirname);
 use IO::File;
-use File::Path;
+use File::Path qw(mkpath);
 #use Data::Dumper;
 
 use HTML::SiteTear::PageFilter;
 
-require HTML::SiteTear::Item;
-our @ISA = qw(HTML::SiteTear::Item);
-our $VERSION = '1.43';
+use base qw(HTML::SiteTear::Item);
+our $VERSION = '1.45';
 
 =head1 NAME
 
@@ -71,17 +69,13 @@ Copy $source_path into new linked path from $parent.
 =cut
 
 sub copy_to_linkpath {
-    #print "start copy_to_linkpath\n";
-    my ($self) = @_;
-    my $parentFile = $self->parent->target_path;
-
-    my $filter;
-    if (defined $_filter_module) {
-        $filter = $_filter_module->new($self);
-    }
-    else {
-        $filter = HTML::SiteTear::PageFilter->new($self);
-    }
+    my ($self) = shift @_;
+    my $filter = do {
+        if (defined $_filter_module) {
+            $_filter_module->new($self);
+        } else {
+            HTML::SiteTear::PageFilter->new($self);
+        }};
     
     my $source_path = $self->source_path;
     unless (-e $source_path) {
@@ -90,17 +84,15 @@ sub copy_to_linkpath {
     }
 
     unless ($self->exists_in_copied_files($source_path)){
-        my $target_path;
-        if (my $target_uri = $self->item_in_filemap($source_path)) {
-            $target_path = $target_uri->file;
-        } else {
-            $target_path = $self->link_uri->file;
-        }
-        
+        my $target_path = do {
+            if (my $target_uri = $self->item_in_filemap($source_path)) {
+                $target_uri->file;
+            } else {
+                $self->link_uri->file;
+            }};
         mkpath(dirname($target_path));
         my $io = IO::File->new("> $target_path") 
                                 or die "Can't open $target_path";
-        #$target_path = Cwd::realpath($target_path);
         $self->target_path($target_path);
         $self->{'OUT'} = $io;
         print "\nCopying HTML...\n";
@@ -139,7 +131,7 @@ sub build_abs_url {
         return $linkpath;
     }
     my $abs_uri = $link_uri->abs($self->source_uri);
-    my $rel_from_root = $abs_uri->rel($self->source_root->site_root_file_uri);
+    my $rel_from_root = $abs_uri->rel($self->source_root->site_root_local_uri);
     my $abs_in_site = $rel_from_root->abs($self->source_root->site_root_uri);
     print "\nConverting to absolute link...\n";
     print "from a link ".$link_uri."\n";
@@ -150,7 +142,7 @@ sub build_abs_url {
 
 =head1 SEE ALOSO
 
-L<HTML::SiteTear>, L<HTML::SiteTear::Item>, L<HTML::SiteTear::CSS>, L<HTML::SiteTear::Root>, L<HTML::SiteTear::dPageFilter>
+L<HTML::SiteTear>, L<HTML::SiteTear::Item>, L<HTML::SiteTear::CSS>, L<HTML::SiteTear::Root>, L<HTML::SiteTear::PageFilter>
 
 =head1 AUTHOR
 
